summaryrefslogtreecommitdiff
path: root/svx/source/form
diff options
context:
space:
mode:
authorMichael T. Whiteley <mike@whiteley.org>2011-12-07 02:33:51 -0800
committerTor Lillqvist <tlillqvist@suse.com>2011-12-08 11:32:41 +0200
commitdcfd4beb213c551f6ef6ba379651bf303bd9017a (patch)
treea819f50716357c2a5561f6b9a09809cfc52d7dbf /svx/source/form
parentad2eb6c4ba3ca36e2302c721a106dac80d266325 (diff)
childs -> children
Diffstat (limited to 'svx/source/form')
-rw-r--r--svx/source/form/fmexpl.cxx16
-rw-r--r--svx/source/form/fmshimp.cxx2
-rw-r--r--svx/source/form/fmvwimp.cxx6
-rw-r--r--svx/source/form/formcontroller.cxx20
-rw-r--r--svx/source/form/navigatortree.cxx8
-rw-r--r--svx/source/form/navigatortreemodel.cxx6
6 files changed, 29 insertions, 29 deletions
diff --git a/svx/source/form/fmexpl.cxx b/svx/source/form/fmexpl.cxx
index b67f2a1250d6..95ae0a8e04a7 100644
--- a/svx/source/form/fmexpl.cxx
+++ b/svx/source/form/fmexpl.cxx
@@ -311,9 +311,9 @@ void FmEntryData::Clear()
}
//------------------------------------------------------------------------
-sal_Bool FmEntryData::IsEqualWithoutChilds( FmEntryData* pEntryData )
+sal_Bool FmEntryData::IsEqualWithoutChildren( FmEntryData* pEntryData )
{
- RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "FmEntryData::IsEqualWithoutChilds" );
+ RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "FmEntryData::IsEqualWithoutChildren" );
if(this == pEntryData)
return sal_True;
@@ -332,7 +332,7 @@ sal_Bool FmEntryData::IsEqualWithoutChilds( FmEntryData* pEntryData )
if( !pEntryData->GetParent() && !pParent )
return sal_True;
- if( !pParent->IsEqualWithoutChilds(pEntryData->GetParent()) )
+ if( !pParent->IsEqualWithoutChildren(pEntryData->GetParent()) )
return sal_False;
return sal_True;
@@ -395,7 +395,7 @@ FmEntryData* FmFormData::Clone()
}
//------------------------------------------------------------------------
-sal_Bool FmFormData::IsEqualWithoutChilds( FmEntryData* pEntryData )
+sal_Bool FmFormData::IsEqualWithoutChildren( FmEntryData* pEntryData )
{
if(this == pEntryData)
return sal_True;
@@ -405,7 +405,7 @@ sal_Bool FmFormData::IsEqualWithoutChilds( FmEntryData* pEntryData )
if( (XForm*)m_xForm.get() != (XForm*)pFormData->GetFormIface().get() )
return sal_False;
- return FmEntryData::IsEqualWithoutChilds( pFormData );
+ return FmEntryData::IsEqualWithoutChildren( pFormData );
}
@@ -571,9 +571,9 @@ Image FmControlData::GetImage(const ImageList& ilNavigatorImages) const
}
//------------------------------------------------------------------------
-sal_Bool FmControlData::IsEqualWithoutChilds( FmEntryData* pEntryData )
+sal_Bool FmControlData::IsEqualWithoutChildren( FmEntryData* pEntryData )
{
- RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "FmControlData::IsEqualWithoutChilds" );
+ RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "FmControlData::IsEqualWithoutChildren" );
if(this == pEntryData)
return sal_True;
@@ -584,7 +584,7 @@ sal_Bool FmControlData::IsEqualWithoutChilds( FmEntryData* pEntryData )
if( (XFormComponent*)m_xFormComponent.get() != (XFormComponent*)pControlData->GetFormComponent().get() )
return sal_False;
- return FmEntryData::IsEqualWithoutChilds( pControlData );
+ return FmEntryData::IsEqualWithoutChildren( pControlData );
}
//------------------------------------------------------------------------
diff --git a/svx/source/form/fmshimp.cxx b/svx/source/form/fmshimp.cxx
index 6aea3ed8f127..e261c21b51fc 100644
--- a/svx/source/form/fmshimp.cxx
+++ b/svx/source/form/fmshimp.cxx
@@ -2703,7 +2703,7 @@ void FmXFormShell::impl_RemoveElement_nothrow(const Reference< XInterface>& Elem
if (xSelSupplier.is())
xSelSupplier->removeSelectionChangeListener(this);
- // remove connection to childs
+ // remove connection to children
const Reference< XIndexContainer> xContainer(Element, UNO_QUERY);
if (xContainer.is())
{
diff --git a/svx/source/form/fmvwimp.cxx b/svx/source/form/fmvwimp.cxx
index ac668ebb5da5..a137968a3ed0 100644
--- a/svx/source/form/fmvwimp.cxx
+++ b/svx/source/form/fmvwimp.cxx
@@ -299,7 +299,7 @@ void SAL_CALL FormViewPageWindowAdapter::makeVisible( const Reference< XControl
}
//------------------------------------------------------------------------
-Reference< XFormController > getControllerSearchChilds( const Reference< XIndexAccess > & xIndex, const Reference< XTabControllerModel > & xModel)
+Reference< XFormController > getControllerSearchChildren( const Reference< XIndexAccess > & xIndex, const Reference< XTabControllerModel > & xModel)
{
if (xIndex.is() && xIndex->getCount())
{
@@ -312,7 +312,7 @@ Reference< XFormController > getControllerSearchChilds( const Reference< XIndex
return xController;
else
{
- xController = getControllerSearchChilds(Reference< XIndexAccess > (xController, UNO_QUERY), xModel);
+ xController = getControllerSearchChildren(Reference< XIndexAccess > (xController, UNO_QUERY), xModel);
if ( xController.is() )
return xController;
}
@@ -333,7 +333,7 @@ Reference< XFormController > FormViewPageWindowAdapter::getController( const Re
return *i;
// the current-round controller isn't the right one. perhaps one of it's children ?
- Reference< XFormController > xChildSearch = getControllerSearchChilds(Reference< XIndexAccess > (*i, UNO_QUERY), xModel);
+ Reference< XFormController > xChildSearch = getControllerSearchChildren(Reference< XIndexAccess > (*i, UNO_QUERY), xModel);
if (xChildSearch.is())
return xChildSearch;
}
diff --git a/svx/source/form/formcontroller.cxx b/svx/source/form/formcontroller.cxx
index 8934926cbc87..7c854bf9f20b 100644
--- a/svx/source/form/formcontroller.cxx
+++ b/svx/source/form/formcontroller.cxx
@@ -1126,7 +1126,7 @@ void SAL_CALL FormController::setActiveTerm( ::sal_Int32 _ActiveTerm ) throw (In
sal_Bool SAL_CALL FormController::hasElements(void) throw( RuntimeException )
{
::osl::MutexGuard aGuard( m_aMutex );
- return !m_aChilds.empty();
+ return !m_aChildren.empty();
}
//------------------------------------------------------------------------------
@@ -1149,7 +1149,7 @@ Reference< XEnumeration > SAL_CALL FormController::createEnumeration(void) thro
sal_Int32 SAL_CALL FormController::getCount(void) throw( RuntimeException )
{
::osl::MutexGuard aGuard( m_aMutex );
- return m_aChilds.size();
+ return m_aChildren.size();
}
//------------------------------------------------------------------------------
@@ -1157,10 +1157,10 @@ Any SAL_CALL FormController::getByIndex(sal_Int32 Index) throw( IndexOutOfBounds
{
::osl::MutexGuard aGuard( m_aMutex );
if (Index < 0 ||
- Index >= (sal_Int32)m_aChilds.size())
+ Index >= (sal_Int32)m_aChildren.size())
throw IndexOutOfBoundsException();
- return makeAny( m_aChilds[ Index ] );
+ return makeAny( m_aChildren[ Index ] );
}
// EventListener
@@ -1237,8 +1237,8 @@ void FormController::disposing(void)
implSetCurrentControl( NULL );
// clean up our children
- for (FmFormControllers::const_iterator i = m_aChilds.begin();
- i != m_aChilds.end(); ++i)
+ for (FmFormControllers::const_iterator i = m_aChildren.begin();
+ i != m_aChildren.end(); ++i)
{
// search the position of the model within the form
Reference< XFormComponent > xForm((*i)->getModel(), UNO_QUERY);
@@ -1258,7 +1258,7 @@ void FormController::disposing(void)
Reference< XComponent > (*i, UNO_QUERY)->dispose();
}
- m_aChilds.clear();
+ m_aChildren.clear();
disposeAllFeaturesAndDispatchers();
@@ -3059,7 +3059,7 @@ void SAL_CALL FormController::addChildController( const Reference< XFormControll
throw IllegalArgumentException( ::rtl::OUString(), *this, 1 );
// TODO: (localized) error message
- m_aChilds.push_back( _ChildController );
+ m_aChildren.push_back( _ChildController );
_ChildController->setParent( *this );
// search the position of the model within the form
@@ -3529,8 +3529,8 @@ void FormController::setMode(const ::rtl::OUString& Mode) throw( NoSupportExcept
else
stopFiltering();
- for (FmFormControllers::const_iterator i = m_aChilds.begin();
- i != m_aChilds.end(); ++i)
+ for (FmFormControllers::const_iterator i = m_aChildren.begin();
+ i != m_aChildren.end(); ++i)
{
Reference< XModeSelector > xMode(*i, UNO_QUERY);
if ( xMode.is() )
diff --git a/svx/source/form/navigatortreemodel.cxx b/svx/source/form/navigatortreemodel.cxx
index 0e89ce1f37c1..e5f3c8501b08 100644
--- a/svx/source/form/navigatortreemodel.cxx
+++ b/svx/source/form/navigatortreemodel.cxx
@@ -822,10 +822,10 @@ namespace svxform
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTreeModel::InsertFormComponent" );
if ( pObject->ISA(SdrObjGroup) )
{ // rekursiv absteigen
- const SdrObjList *pChilds = ((SdrObjGroup*)pObject)->GetSubList();
- for ( sal_uInt16 i=0; i<pChilds->GetObjCount(); ++i )
+ const SdrObjList *pChildren = ((SdrObjGroup*)pObject)->GetSubList();
+ for ( sal_uInt16 i=0; i<pChildren->GetObjCount(); ++i )
{
- SdrObject* pCurrent = pChilds->GetObj(i);
+ SdrObject* pCurrent = pChildren->GetObj(i);
if (!InsertFormComponent(rHint, pCurrent))
return sal_False;
}
diff --git a/svx/source/form/navigatortree.cxx b/svx/source/form/navigatortree.cxx
index 4b67905fc43b..df1c845e9c84 100644
--- a/svx/source/form/navigatortree.cxx
+++ b/svx/source/form/navigatortree.cxx
@@ -563,7 +563,7 @@ namespace svxform
while( pCurEntry )
{
pCurEntryData = (FmEntryData*)pCurEntry->GetUserData();
- if( pCurEntryData && pCurEntryData->IsEqualWithoutChilds(pEntryData) )
+ if( pCurEntryData && pCurEntryData->IsEqualWithoutChildren(pEntryData) )
return pCurEntry;
pCurEntry = Next( pCurEntry );
@@ -658,7 +658,7 @@ namespace svxform
Expand( m_pRootEntry );
//////////////////////////////////////////////////////////////////////
- // Childs einfuegen
+ // Children einfuegen
FmEntryDataList* pChildList = pEntryData->GetChildList();
size_t nChildCount = pChildList->size();
FmEntryData* pChildData;
@@ -914,7 +914,7 @@ namespace svxform
m_aDropActionType = DA_SCROLLDOWN;
bNeedTrigger = sal_True;
} else
- { // auf einem Entry mit Childs, der nicht aufgeklappt ist ?
+ { // auf einem Entry mit Children, der nicht aufgeklappt ist ?
SvLBoxEntry* pDropppedOn = GetEntry(aDropPos);
if (pDropppedOn && (GetChildCount(pDropppedOn) > 0) && !IsExpanded(pDropppedOn))
{
@@ -1964,7 +1964,7 @@ namespace svxform
// und selektiere diesen (waere irgendwie intuitiver ;)) 2) ich gehe durch alle meine SvLBoxEntries und selektiere
// genau die, die ich in der SelectList finde
// 1) braucht O(k*n) (k=Laenge der SelectList, n=Anzahl meiner Entries), plus den Fakt, dass FindEntry nicht den
// Pointer auf die UserDaten vergleicht, sondern ein aufwendigeres IsEqualWithoutChilds durchfuehrt
// 2) braucht O(n*log k), dupliziert aber etwas Code (naemlich den aus FindEntry)
// da das hier eine relativ oft aufgerufenen Stelle sein koennte (bei jeder Aenderung in der Markierung in der View !),
// nehme ich doch lieber letzteres
@@ -1964,7 +1964,7 @@ namespace svxform
// genau die, die ich in der SelectList finde
// 1) braucht O(k*n) (k=Laenge der SelectList, n=Anzahl meiner Entries), plus den Fakt, dass FindEntry nicht den
- // Pointer auf die UserDaten vergleicht, sondern ein aufwendigeres IsEqualWithoutChilds durchfuehrt
+ // Pointer auf die UserDaten vergleicht, sondern ein aufwendigeres IsEqualWithoutChildren durchfuehrt
// 2) braucht O(n*log k), dupliziert aber etwas Code (naemlich den aus FindEntry)
// da das hier eine relativ oft aufgerufenen Stelle sein koennte (bei jeder Aenderung in der Markierung in der View !),